<?php
/*
Plugin Name: Social Links Manager
Description: A plugin to manage social links and display them via a shortcode. Links left empty will not display on the frontend.
Version: 1.0.1
Author: Sagar Jain
License: GPL2
License URI: https://www.gnu.org/licenses/gpl-2.0.html
Text Domain: social-links-manager
*/

// Prevent direct access
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

// Register settings and admin menu
add_action( 'admin_menu', 'social_links_manager_add_admin_menu' );
add_action( 'admin_init', 'social_links_manager_register_settings' );

function social_links_manager_add_admin_menu() {
    add_menu_page(
        'Social Links Manager',
        'Social Links Manager',
        'manage_options',
        'social-links-manager',
        'social_links_manager_admin_page',
        'dashicons-share',
        6
    );
}

function social_links_manager_register_settings() {
    register_setting( 'social_links_manager_options_group', 'social_links_manager_links', 'social_links_manager_sanitize_links' );
}

function social_links_manager_sanitize_links( $input ) {
    return array_map( 'esc_url_raw', (array) $input );
}

// Render admin page
function social_links_manager_admin_page() {
    ?>
    <div class="wrap">
        <h1><?php esc_html_e( 'Social Links Manager', 'social-links-manager' ); ?></h1>
        <form method="post" action="options.php">
            <?php
            settings_fields( 'social_links_manager_options_group' );
            $links = get_option( 'social_links_manager_links', array( 'facebook' => '', 'twitter' => '', 'instagram' => '' ) );
            ?>
            <table class="form-table">
                <tr>
                    <th scope="row"><?php esc_html_e( 'Facebook URL', 'social-links-manager' ); ?></th>
                    <td><input type="url" name="social_links_manager_links[facebook]" value="<?php echo esc_attr( $links['facebook'] ?? '' ); ?>" class="regular-text"></td>
                </tr>
                <tr>
                    <th scope="row"><?php esc_html_e( 'Twitter URL', 'social-links-manager' ); ?></th>
                    <td><input type="url" name="social_links_manager_links[twitter]" value="<?php echo esc_attr( $links['twitter'] ?? '' ); ?>" class="regular-text"></td>
                </tr>
                <tr>
                    <th scope="row"><?php esc_html_e( 'Instagram URL', 'social-links-manager' ); ?></th>
                    <td><input type="url" name="social_links_manager_links[instagram]" value="<?php echo esc_attr( $links['instagram'] ?? '' ); ?>" class="regular-text"></td>
                </tr>
            </table>
            <?php submit_button(); ?>
        </form>
    </div>
    <?php
}

// Shortcode to display social links
function social_links_manager_shortcode() {
    $links = get_option( 'social_links_manager_links', array( 'facebook' => '', 'twitter' => '', 'instagram' => '' ) );
    $output = '<div class="social-links">';

    foreach ( $links as $platform => $url ) {
        if ( ! empty( $url ) ) {
            $output .= sprintf( '<a href="%s" target="_blank" rel="noopener noreferrer">%s</a>', esc_url( $url ), ucfirst( $platform ) );
        }
    }
    $output .= '</div>';
    
    return $output;
}
add_shortcode( 'social_links', 'social_links_manager_shortcode' );
?>
